@@ -1,7 +1,7 @@
 /*
  *  editdlgtypes.cpp  -  dialogs to create or edit alarm or alarm template types
  *  Program:  kalarm
- *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2020 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 
 #include "emailidcombo.h"
 #include "fontcolourbutton.h"
+#include "functions.h"
 #include "kalarmapp.h"
 #include "kamail.h"
 #include "latecancel.h"
@@ -39,6 +40,7 @@
 #include "lib/buttongroup.h"
 #include "lib/checkbox.h"
 #include "lib/colourbutton.h"
+#include "lib/dragdrop.h"
 #include "lib/file.h"
 #include "lib/lineedit.h"
 #include "lib/messagebox.h"
@@ -179,6 +181,7 @@ void EditDisplayAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
     // Text message edit box
     mTextMessageEdit = new TextEdit(parent);
     mTextMessageEdit->setLineWrapMode(KTextEdit::NoWrap);
+    mTextMessageEdit->enableEmailDrop();         // allow drag-and-drop of emails onto this widget
     mTextMessageEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter the text of the alarm message. It may be multi-line."));
     connect(mTextMessageEdit, &TextEdit::textChanged, this, &EditDisplayAlarmDlg::contentsChanged);
     frameLayout->addWidget(mTextMessageEdit);
@@ -219,7 +222,7 @@ void EditDisplayAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
     mSoundPicker->setFixedSize(mSoundPicker->sizeHint());
     connect(mSoundPicker, &SoundPicker::changed, this, &EditDisplayAlarmDlg::contentsChanged);
     hlayout->addWidget(mSoundPicker);
-    hlayout->addSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
+    hlayout->addSpacing(2 * style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing));
     hlayout->addStretch();
 
     // Font and colour choice button and sample text
@@ -766,14 +769,16 @@ void EditCommandAlarmDlg::type_init(QWidget* parent, QVBoxLayout* frameLayout)
     connect(mCmdEdit, &CommandEdit::changed, this, &EditCommandAlarmDlg::contentsChanged);
     frameLayout->addWidget(mCmdEdit);
 
+    mCmdDontShowError = new CheckBox(i18nc("@option:check", "Do not notify errors"), parent);
+    mCmdDontShowError->setWhatsThis(i18nc("@info:whatsthis", "Do not show error message if the command fails."));
+    frameLayout->addWidget(mCmdDontShowError, 0, Qt::AlignLeft);
+    connect(mCmdDontShowError, &CheckBox::toggled, this, &EditCommandAlarmDlg::contentsChanged);
+
     // What to do with command output
 
     mCmdOutputBox = new QGroupBox(i18nc("@title:group", "Command Output"), parent);
     frameLayout->addWidget(mCmdOutputBox);
     QVBoxLayout* vlayout = new QVBoxLayout(mCmdOutputBox);
-    int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
-    vlayout->setContentsMargins(dcm, dcm, dcm, dcm);
-    vlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mCmdOutputGroup = new ButtonGroup(mCmdOutputBox);
     connect(mCmdOutputGroup, &ButtonGroup::buttonSet, this, &EditCommandAlarmDlg::contentsChanged);
 
@@ -845,6 +850,7 @@ void EditCommandAlarmDlg::type_initValues(const KAEvent* event)
         if (logType == mCmdLogToFile)
             mCmdLogFileEdit->setText(event->logFile());    // set file name before setting radio button
         logType->setChecked(true);
+        mCmdDontShowError->setChecked(event->commandHideError());
     }
     else
     {
@@ -852,6 +858,7 @@ void EditCommandAlarmDlg::type_initValues(const KAEvent* event)
         mCmdEdit->setScript(Preferences::defaultCmdScript());
         mCmdLogFileEdit->setText(Preferences::defaultCmdLogFile());    // set file name before setting radio button
         mCmdOutputGroup->setButton(Preferences::defaultCmdLogType());
+        mCmdDontShowError->setChecked(false);
     }
     slotCmdScriptToggled(mCmdEdit->isScript());
 }
@@ -886,6 +893,7 @@ void EditCommandAlarmDlg::setReadOnly(bool readOnly)
     if (!isTemplate()  &&  !ShellProcess::authorised())
         readOnly = true;     // don't allow editing of existing command alarms in kiosk mode
     mCmdEdit->setReadOnly(readOnly);
+    mCmdDontShowError->setReadOnly(readOnly);
     mCmdExecInTerm->setReadOnly(readOnly);
     mCmdLogToFile->setReadOnly(readOnly);
     mCmdDiscardOutput->setReadOnly(readOnly);
@@ -898,9 +906,10 @@ void EditCommandAlarmDlg::setReadOnly(bool readOnly)
 void EditCommandAlarmDlg::saveState(const KAEvent* event)
 {
     EditAlarmDlg::saveState(event);
-    mSavedCmdScript      = mCmdEdit->isScript();
-    mSavedCmdOutputRadio = mCmdOutputGroup->checkedButton();
-    mSavedCmdLogFile     = mCmdLogFileEdit->text();
+    mSavedCmdScript        = mCmdEdit->isScript();
+    mSavedCmdDontShowError = mCmdDontShowError->isChecked();
+    mSavedCmdOutputRadio   = mCmdOutputGroup->checkedButton();
+    mSavedCmdLogFile       = mCmdLogFileEdit->text();
 }
 
 /******************************************************************************
@@ -911,8 +920,9 @@ void EditCommandAlarmDlg::saveState(const KAEvent* event)
 */
 bool EditCommandAlarmDlg::type_stateChanged() const
 {
-    if (mSavedCmdScript      != mCmdEdit->isScript()
-    ||  mSavedCmdOutputRadio != mCmdOutputGroup->checkedButton())
+    if (mSavedCmdScript        != mCmdEdit->isScript()
+    ||  mSavedCmdOutputRadio   != mCmdOutputGroup->checkedButton()
+    ||  mSavedCmdDontShowError != mCmdDontShowError->isChecked())
         return true;
     if (mCmdOutputGroup->checkedButton() == mCmdLogToFile)
     {
@@ -942,6 +952,7 @@ KAEvent::Flags EditCommandAlarmDlg::getAlarmFlags() const
     KAEvent::Flags flags = EditAlarmDlg::getAlarmFlags();
     if (mCmdEdit->isScript())                               flags |= KAEvent::SCRIPT;
     if (mCmdOutputGroup->checkedButton() == mCmdExecInTerm) flags |= KAEvent::EXEC_IN_XTERM;
+    if (mCmdDontShowError->isChecked())                     flags |= KAEvent::DONT_SHOW_ERROR;
     return flags;
 }
 
@@ -1733,7 +1744,6 @@ CommandEdit::CommandEdit(QWidget* parent)
 {
     QVBoxLayout* vlayout = new QVBoxLayout(this);
     vlayout->setContentsMargins(0, 0, 0, 0);
-    vlayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mTypeScript = new CheckBox(EditCommandAlarmDlg::i18n_chk_EnterScript(), this);
     mTypeScript->setFixedSize(mTypeScript->sizeHint());
     mTypeScript->setWhatsThis(i18nc("@info:whatsthis", "Check to enter the contents of a script instead of a shell command line"));
@@ -1845,7 +1855,7 @@ QSize CommandEdit::minimumSizeHint() const
 {
     QSize t(mTypeScript->minimumSizeHint());
     QSize s(mCommandEdit->minimumSizeHint().expandedTo(mScriptEdit->minimumSizeHint()));
-    s.setHeight(s.height() + style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing) + t.height());
+    s.setHeight(s.height() + style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing) + t.height());
     if (s.width() < t.width())
         s.setWidth(t.width());
     return s;
@@ -1865,11 +1875,78 @@ TextEdit::TextEdit(QWidget* parent)
     setMinimumSize(tsize);
 }
 
+void TextEdit::enableEmailDrop()
+{
+    mEmailDrop = true;
+    setAcceptDrops(true);   // allow drag-and-drop onto this widget
+}
+
 void TextEdit::dragEnterEvent(QDragEnterEvent* e)
 {
     if (KCalUtils::ICalDrag::canDecode(e->mimeData()))
+    {
         e->ignore();   // don't accept "text/calendar" objects
+        return;
+    }
+    if (mEmailDrop  &&  DragDrop::mayHaveRFC822(e->mimeData()))
+    {
+        e->acceptProposedAction();
+        return;
+    }
     KTextEdit::dragEnterEvent(e);
 }
 
+void TextEdit::dragMoveEvent(QDragMoveEvent* e)
+{
+    if (mEmailDrop  &&  DragDrop::mayHaveRFC822(e->mimeData()))
+    {
+        e->acceptProposedAction();
+        return;
+    }
+    KTextEdit::dragMoveEvent(e);
+}
+
+/******************************************************************************
+* Called when an object is dropped on the widget.
+*/
+void TextEdit::dropEvent(QDropEvent* e)
+{
+    const QMimeData* data = e->mimeData();
+    if (mEmailDrop)
+    {
+        AlarmText alarmText;
+        bool haveEmail = false;
+        if (DragDrop::dropRFC822(data, alarmText))
+        {
+            // Email message(s). Ignore all but the first.
+            qCDebug(KALARM_LOG) << "TextEdit::dropEvent: email";
+            haveEmail = true;
+        }
+        else
+        {
+            QUrl url;
+            Akonadi::Item item;
+            if (DragDrop::dropAkonadiEmail(data, url, item, alarmText))
+            {
+                // It's an email held in Akonadi
+                qCDebug(KALARM_LOG) << "TextEdit::dropEvent: Akonadi email";
+                haveEmail = true;
+            }
+        }
+        if (haveEmail)
+        {
+            if (!alarmText.isEmpty())
+                setPlainText(alarmText.displayText());
+            return;
+        }
+    }
+    QString text;
+    if (DragDrop::dropPlainText(data, text))
+    {
+        setPlainText(text);
+        return;
+    }
+    KTextEdit::dropEvent(e);
+}
+
 // vim: et sw=4:
